﻿'' Copyright {2010} by Autodesk, Inc.
''
'' Permission to use, copy, modify, and distribute this software for
'' any purpose and without fee is hereby granted, provided that the
'' above copyright notice appears in all copies and  that both that
'' copyright notice and the limited warranty and  restricted rights
'' notice below appear in all supporting  documentation.
''
'' AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS.
'' AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
'' MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE. AUTODESK, INC.
'' DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL BE
'' UNINTERRUPTED OR ERROR FREE.
''
'' Use, duplication, or disclosure by the U.S. Government is subject to
'' restrictions set forth in FAR 52.227-19 (Commercial Computer
'' Software - Restricted Rights) and DFAR 252.227-7013(c)(1)(ii)
'' (Rights in Technical Data and Computer Software), as applicable.


'' The following managed assemblies are referenced in this sample -

''  acmgd.dll  @ C:\Program Files\Autodesk\AutoCAD Civil 3D 2011\acmgd.dll
''  acdbmgd.dll @ C:\Program Files\Autodesk\AutoCAD Civil 3D 2011\acdbmgd.dll
''
''  AecBaseMgd.dll  @ C:\Program Files\Autodesk\AutoCAD Civil 3D 2011\AecBaseMgd.dll
''  AeccDbMgd.dll   @ C:\Program Files\Autodesk\AutoCAD Civil 3D 2011\AeccDbMgd.dll
''
''  Civil 3D library are stores as TLB files at Program Files folder, 
''  usually c:\Program Files, but there are some specific folders:
''  Civil3D 2011: %PROGRAMFILES%\Common Files\Autodesk Shared\Civil Engineering 80
''
''  You will also need AecBase type library:
''  Civil3D 2011: %PROGRAMFILES%\Common Files\Autodesk Shared\AecXBase65.tlb and AecXUIBase65.tlb
'
''  ********************************************************************************
''  This Sample demonstrates usage of many .NET API functions of AutoCAD Civil 3D 2011 
''  
''  ***********************************************************************************

Option Explicit On
Option Strict Off


Imports System.Windows.Forms

'' AutoCAD namespaces
Imports Autodesk.AutoCAD.Runtime
Imports Autodesk.AutoCAD.ApplicationServices
Imports Autodesk.AutoCAD.DatabaseServices
Imports Autodesk.AutoCAD.EditorInput
Imports Autodesk.AutoCAD.Geometry

'' Civil - Land namspaces
Imports Autodesk.Civil.DatabaseServices
Imports Autodesk.Civil.DatabaseServices.Styles
Imports Autodesk.Civil.ApplicationServices
Imports Autodesk.Civil.Land.DatabaseServices
Imports Autodesk.Civil.Land.DatabaseServices.Styles


'' Civil COM Interop
Imports Autodesk.AECC.Interop.Land
Imports Autodesk.AECC.Interop.UiLand


Public Class Commands

    <CommandMethod("PSCRCG")> _
Public Sub CreateCOGOPoint()

        '' This sample Demonstrates Creation of COGO Point Civil 3D 2011 
        '' 
        '' Created by Partha P. Sarkar - DevTech, Autodesk

        Dim ed As Editor = Autodesk.AutoCAD.ApplicationServices.Application.DocumentManager.MdiActiveDocument.Editor

        Dim oAcadApp As Autodesk.AutoCAD.Interop.AcadApplication = Nothing
        Dim oAeccApp As Autodesk.AECC.Interop.UiLand.AeccApplication = Nothing
        Dim oAeccDoc As Autodesk.AECC.Interop.UiLand.AeccDocument = Nothing
        Dim oAeccDB As Autodesk.AECC.Interop.Land.AeccDatabase = Nothing

        Using trans As Transaction = HostApplicationServices.WorkingDatabase.TransactionManager.StartTransaction()


            Try
                If oAcadApp Is Nothing Then
                    oAcadApp = GetObject(, "AutoCAD.Application")
                End If
            Catch ex As Exception
                ed.WriteMessage(ex.Message)
            End Try

            Try
                '' Getting the application object

                oAeccApp = oAcadApp.GetInterfaceObject("AeccXUiLand.AeccApplication.8.0")
                oAeccDoc = oAeccApp.ActiveDocument
                oAeccDB = oAeccApp.ActiveDocument.Database

                '' Creating a COGO point in Civil 3D

                Dim oPoint As Autodesk.AECC.Interop.Land.AeccPoint = Nothing
                Dim pointLocation As Point3d = Nothing

                '' use PromptPointOptions to select a location.

                Dim promptPtOp As PromptPointOptions = New PromptPointOptions(vbCrLf + "Select the Location to create the COGO Point : ")
                promptPtOp.LimitsChecked = True
                promptPtOp.AllowNone = False

                Dim promptPtRes As PromptPointResult = ed.GetPoint(promptPtOp)

                If promptPtRes.Status <> PromptStatus.OK Then
                    ed.WriteMessage("Exiting! Try Again !")
                    Exit Sub
                End If

                pointLocation = promptPtRes.Value

                Dim location(0 To 2) As Double

                location(0) = pointLocation.X
                location(1) = pointLocation.Y
                location(2) = pointLocation.Z

                oPoint = oAeccDoc.Points.Add(CType(location, Object))
                oPoint.RawDescription = "DevCamp DEMO "
                oPoint.Name = "Base Point"
                oPoint.Number = 10

                trans.Commit()
            Catch ex As Exception
                ed.WriteMessage("Error : ", ex.Message & vbCrLf)
            End Try
        End Using
    End Sub


    <CommandMethod("PSCRAL")> _
Public Sub CreateAlignment()

        '' This sample Demonstrates Creation of COM Alingnment object and Casting to .NET Alignment - Civil 3D 2011 
        '' 
        '' Created by Partha P. Sarkar - DevTech, Autodesk

        Dim ed As Editor = Autodesk.AutoCAD.ApplicationServices.Application.DocumentManager.MdiActiveDocument.Editor

        Dim oAcadApp As Autodesk.AutoCAD.Interop.AcadApplication = Nothing
        Dim oAeccApp As Autodesk.AECC.Interop.UiLand.AeccApplication = Nothing
        Dim oAeccDoc As Autodesk.AECC.Interop.UiLand.AeccDocument = Nothing
        Dim oAeccDB As Autodesk.AECC.Interop.Land.AeccDatabase = Nothing

        Using trans As Transaction = HostApplicationServices.WorkingDatabase.TransactionManager.StartTransaction()
            'Dim civilDoc As CivilDocument = Autodesk.Civil.ApplicationServices.CivilApplication.ActiveDocument
            Try
                If oAcadApp Is Nothing Then
                    oAcadApp = GetObject(, "AutoCAD.Application")
                End If
            Catch ex As Exception
                ed.WriteMessage(ex.Message)
            End Try

            Try
                oAeccApp = oAcadApp.GetInterfaceObject("AeccXUiLand.AeccApplication.8.0")
                oAeccDoc = oAeccApp.ActiveDocument
                oAeccDB = oAeccApp.ActiveDocument.Database

                Dim oAlignment As Autodesk.AECC.Interop.Land.AeccAlignment = Nothing

                ' Select the Polyline
                Dim promptEntOp As New PromptEntityOptions(vbCrLf + "Select a Polyline : ")
                Dim promptEntRs As PromptEntityResult
                promptEntRs = ed.GetEntity(promptEntOp)
                If promptEntRs.Status <> PromptStatus.OK Then
                    ed.WriteMessage("Exiting! Try Again !")
                    Exit Sub
                End If


                Dim plineIdInt As Integer = promptEntRs.ObjectId.OldIdPtr

                oAlignment = oAeccDoc.AlignmentsSiteless.AddFromPolyline("CL State Highway", "0", plineIdInt, _
                                                                         oAeccDoc.AlignmentStyles.Item(0), oAeccDoc.AlignmentLabelStyleSets.Item(0), True, True)



                ''try Cast from COM to .NET and open it using the transaction, for READ or WRITE

                Dim alignment As Autodesk.Civil.Land.DatabaseServices.Alignment = Nothing
                alignment = TryCast(trans.GetObject(New ObjectId(New IntPtr(oAlignment.ObjectID)), OpenMode.ForWrite), Alignment)

                '' Check if the cast succeeded?
                If Not (alignment Is Nothing) Then

                    Dim designSpeed As DesignSpeed = Nothing
                    ' Now add a new Design speed for the same station
                    designSpeed = alignment.DesignSpeeds.Add(0.0, 60.0)
                    DesignSpeed.Comment = "This is a Straightway"


                    ' lets add Design Speed 40 mph at Station  200.00

                    designSpeed = alignment.DesignSpeeds.Add(200.0, 40.0)
                    DesignSpeed.Comment = "Start of curve"

                    ' lets add Design Speed 70 mph at Station  301.00

                    designSpeed = alignment.DesignSpeeds.Add(301.0, 70.0)
                    DesignSpeed.Comment = "End of Curve and Starting of Straightway"

                    ' ensure the alignment design is speed-based
                    alignment.UseDesignSpeed = True
                End If

                trans.Commit()
            Catch ex As Exception
                ed.WriteMessage("Error : ", ex.Message & vbCrLf)
            End Try
        End Using
    End Sub

End Class
