﻿'' Copyright {2010} by Autodesk, Inc.
''
'' Permission to use, copy, modify, and distribute this software for
'' any purpose and without fee is hereby granted, provided that the
'' above copyright notice appears in all copies and  that both that
'' copyright notice and the limited warranty and  restricted rights
'' notice below appear in all supporting  documentation.
''
'' AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS.
'' AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
'' MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE. AUTODESK, INC.
'' DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL BE
'' UNINTERRUPTED OR ERROR FREE.
''
'' Use, duplication, or disclosure by the U.S. Government is subject to
'' restrictions set forth in FAR 52.227-19 (Commercial Computer
'' Software - Restricted Rights) and DFAR 252.227-7013(c)(1)(ii)
'' (Rights in Technical Data and Computer Software), as applicable.


'' The following managed assemblies are referenced in this sample -

''  acmgd.dll  @ C:\Program Files\Autodesk\AutoCAD Civil 3D 2011\acmgd.dll
''  acdbmgd.dll @ C:\Program Files\Autodesk\AutoCAD Civil 3D 2011\acdbmgd.dll
''
''  AecBaseMgd.dll  @ C:\Program Files\Autodesk\AutoCAD Civil 3D 2011\AecBaseMgd.dll
''  AeccDbMgd.dll   @ C:\Program Files\Autodesk\AutoCAD Civil 3D 2011\AeccDbMgd.dll
'
''  ********************************************************************************
''  This Sample demonstrates usage of many .NET API functions of AutoCAD Civil 3D 2011 
''  
''  ***********************************************************************************

'' AutoCAD namespaces
Imports Autodesk.AutoCAD.Runtime
Imports Autodesk.AutoCAD.ApplicationServices
Imports Autodesk.AutoCAD.DatabaseServices
Imports Autodesk.AutoCAD.EditorInput
Imports Autodesk.AutoCAD.Geometry


'' Civil - Land namspaces
Imports Autodesk.Civil.DatabaseServices
Imports Autodesk.Civil.ApplicationServices
Imports Autodesk.Civil.Land.DatabaseServices
Imports Autodesk.Civil.Land.DatabaseServices.Styles
Imports Autodesk.Civil.DatabaseServices.LabelGroup
Imports Autodesk.Civil.DatabaseServices.Styles.LabelSetStylesRoot


Public Class Commands



    <CommandMethod("Hello")> _
Public Sub HelloWorld()


        '' This is a typical Hello World sample for Civil 3D 2011 using the new .NET API - 
        '' 
        '' Created by Partha P. Sarkar - DevTech, Autodesk

        Dim ed As Editor = Autodesk.AutoCAD.ApplicationServices.Application.DocumentManager.MdiActiveDocument.Editor

        Dim civilDoc As CivilDocument = Autodesk.Civil.ApplicationServices.CivilApplication.ActiveDocument

        Try

            Dim surfaceIds As ObjectIdCollection = civilDoc.GetSurfaceIds()
            Dim siteIds As ObjectIdCollection = civilDoc.GetSiteIds()
            Dim alignmentIds As ObjectIdCollection = civilDoc.GetAlignmentIds()

            ed.WriteMessage(vbCrLf + "Hello World !")
            ed.WriteMessage(vbCrLf + "Product Type : " + Autodesk.Civil.ApplicationServices.CivilApplication.ActiveProduct.ToString())
            ed.WriteMessage(vbCrLf + "This Civil 3D DWG has " + surfaceIds.Count.ToString() + "  " + "Surfaces")
            ed.WriteMessage(vbCrLf + "This Civil 3D DWG has " + siteIds.Count.ToString() + "  " + "Sites")
            ed.WriteMessage(vbCrLf + "This Civil 3D DWG has " + alignmentIds.Count.ToString + "  " + "Alignments")

        Catch ex As Exception

            ed.WriteMessage("Exception Message is  : " + ex.Message.ToString())

        End Try
    End Sub

    <CommandMethod("PSDSETTINGS")> _
Public Sub AccessDWGSettings()

        '' This sample Demonstrates Accessing Drawing & Feature Settings using the new .NET API in Civil 3D 2011 / 2010 - 
        '' Created by Partha Sarkar - DevTech, Autodesk

        ''Drawing settings and general ambient settings are in the Autodesk::Civil::Settings namespace, 
        '' while feature and command settings are in the namespace for the related feature. 
        '' For example, alignment-related ambient and command settings are in the Autodesk::Civil::Land::Settings namespace. 


        Dim trans As Transaction = HostApplicationServices.WorkingDatabase.TransactionManager.StartTransaction()
        Dim civilDoc As CivilDocument = Autodesk.Civil.ApplicationServices.CivilApplication.ActiveDocument
        Dim ed As Editor = Autodesk.AutoCAD.ApplicationServices.Application.DocumentManager.MdiActiveDocument.Editor

        Try

            ed.WriteMessage(vbCrLf + "Default Driving Direction Settings :  " + civilDoc.Settings.DrawingSettings.AmbientSettings.General.DrivingDirection.Value.ToString())
            ' Now check and change the DrawingSettings.AmbientSettings.General.DrivingDirection

            If (civilDoc.Settings.DrawingSettings.AmbientSettings.General.DrivingDirection.Value <> Autodesk.Civil.DrivingDirectionType.RightSideOfTheRoad) Then

                civilDoc.Settings.DrawingSettings.AmbientSettings.General.DrivingDirection.Value = Autodesk.Civil.DrivingDirectionType.RightSideOfTheRoad
                ed.WriteMessage(vbCrLf + "Driving Direction Settings Is Now Set To:  " + civilDoc.Settings.DrawingSettings.AmbientSettings.General.DrivingDirection.Value.ToString())

            Else

                ed.WriteMessage(vbCrLf + "Driving Direction Settings Is Already Set To:  " + civilDoc.Settings.DrawingSettings.AmbientSettings.General.DrivingDirection.Value.ToString())

            End If
            

            trans.Commit()
        Catch ex As Exception

            ed.WriteMessage("Exception Message is  : " + ex.Message.ToString())

        Finally
            trans.Dispose()
        End Try

    End Sub


    <CommandMethod("PSFSETTINGS")> _
Public Sub AccessFeatureSettings()

        '' This sample Demonstrates how to access a Feature settings using the new .NET API in Civil 3D 2011 / 2010 - 
        '' Created by Partha Sarkar - DevTech, Autodesk

        ''Drawing settings and general ambient settings are in the Autodesk::Civil::Settings namespace, 
        '' while feature and command settings are in the namespace for the related feature. 
        '' For example, alignment-related ambient and command settings are in the Autodesk::Civil::Land::Settings namespace. 


        Dim trans As Transaction = HostApplicationServices.WorkingDatabase.TransactionManager.StartTransaction()
        Dim civilDoc As CivilDocument = Autodesk.Civil.ApplicationServices.CivilApplication.ActiveDocument
        Dim ed As Editor = Autodesk.AutoCAD.ApplicationServices.Application.DocumentManager.MdiActiveDocument.Editor

        Try

            Dim alignmentSetting As Autodesk.Civil.Land.Settings.SettingsAlignment = civilDoc.Settings.GetSettings(Of Autodesk.Civil.Land.Settings.SettingsAlignment)()

            ed.WriteMessage(vbCrLf + "Current Design Speed Value is  :  " + alignmentSetting.CriteriaBasedDesignOptions.DesignSpeed.Value.ToString())

            alignmentSetting.CriteriaBasedDesignOptions.DesignSpeed.Value = 200

            ed.WriteMessage(vbCrLf + "After Change Design Speed Value is  :  " + alignmentSetting.CriteriaBasedDesignOptions.DesignSpeed.Value.ToString())

            trans.Commit()
        Catch ex As Exception
            ed.WriteMessage("Exception Message is  : " + ex.Message.ToString())
        Finally
            trans.Dispose()
       
        End Try

    End Sub



    <CommandMethod("PSCRALST")> _
Public Sub CreateAlignmentStyle()

        '' This sample Demonstrates creating Alignment Style using the new .NET API in Civil 3D 2011 / 2010 - 
        '' Created by Partha Sarkar - DevTech, Autodesk

        Dim trans As Transaction = HostApplicationServices.WorkingDatabase.TransactionManager.StartTransaction()
        Dim civilDoc As CivilDocument = Autodesk.Civil.ApplicationServices.CivilApplication.ActiveDocument
        Dim ed As Editor = Autodesk.AutoCAD.ApplicationServices.Application.DocumentManager.MdiActiveDocument.Editor

        Try
            Dim oAlignmentSTName As String = "Demo_Alignment_Style"
            Dim oAlignmentStyle As Autodesk.Civil.Land.DatabaseServices.Styles.AlignmentStyle = Nothing
            Dim alignmentStyleId As ObjectId

            ' Check if a style by this name already exists.  

            Try
                alignmentStyleId = civilDoc.Styles.AlignmentStyles.Item(oAlignmentSTName)
                If (alignmentStyleId.IsValid) Then
                    MsgBox("Style : " + oAlignmentSTName.ToString + " " + "Already exists in thsi Dwg !")
                    Exit Sub
                End If
            Catch
                alignmentStyleId = Autodesk.AutoCAD.DatabaseServices.ObjectId.Null
            End Try

            If (alignmentStyleId.IsNull) Then

                alignmentStyleId = civilDoc.Styles.AlignmentStyles.Add(oAlignmentSTName)

                If (alignmentStyleId = Nothing) Then
                    MsgBox("Error setting an Alignment Style: " & Err.Description)
                End If
            End If

            oAlignmentStyle = trans.GetObject(alignmentStyleId, OpenMode.ForWrite)

            ' Getting and setting style attributes for StyleBase objects 
            'requires using a GetDisplayStyle*() method rather than a property.

            oAlignmentStyle.GetDisplayStyleModel(AlignmentDisplayStyleType.Arrow).Visible = False
            oAlignmentStyle.GetDisplayStylePlan(AlignmentDisplayStyleType.Arrow).Visible = False

            ' Display curves using a green color 
            oAlignmentStyle.GetDisplayStyleModel(AlignmentDisplayStyleType.Curve).Color = Autodesk.AutoCAD.Colors.Color.FromRgb(58, 191, 13)
            oAlignmentStyle.GetDisplayStylePlan(AlignmentDisplayStyleType.Curve).Color = Autodesk.AutoCAD.Colors.Color.FromRgb(58, 191, 13)
            oAlignmentStyle.GetDisplayStyleModel(AlignmentDisplayStyleType.Curve).Visible = True
            oAlignmentStyle.GetDisplayStylePlan(AlignmentDisplayStyleType.Curve).Visible = True


            ' Display straight sections in blue.
            oAlignmentStyle.GetDisplayStyleModel(AlignmentDisplayStyleType.Line).Color = Autodesk.AutoCAD.Colors.Color.FromRgb(0, 0, 255) ' blue
            oAlignmentStyle.GetDisplayStylePlan(AlignmentDisplayStyleType.Line).Color = Autodesk.AutoCAD.Colors.Color.FromRgb(0, 0, 255) ' blue
            oAlignmentStyle.GetDisplayStyleModel(AlignmentDisplayStyleType.Line).Visible = True
            oAlignmentStyle.GetDisplayStylePlan(AlignmentDisplayStyleType.Line).Visible = True

            oAlignmentStyle.EnableRadiusSnap = True
            oAlignmentStyle.RadiusSnapValue = 0.05 ' set a Radius Snap Value

            trans.Commit()
        Catch ex As Exception

            ed.WriteMessage("Exception Message is  : " + ex.Message.ToString())

        Finally
            trans.Dispose()
        End Try

    End Sub




    <CommandMethod("PSCRALIGN")> _
Public Sub CreateAlignmentFromPLine()

        '' This sample Demonstrates Creation of an Alignment in Civil 3D 2011 using the new .NET API - 
        '' User need to select a Polyline which will be converted to an Aligne
        '' Created by Partha P. Sarkar - DevTech, Autodesk

        Dim ed As Editor = Autodesk.AutoCAD.ApplicationServices.Application.DocumentManager.MdiActiveDocument.Editor

        ' Select the Polyline
        Dim promptEntOp As New PromptEntityOptions(vbCrLf + "Select a Polyline : ")
        Dim promptEntRs As PromptEntityResult
        promptEntRs = ed.GetEntity(promptEntOp)
        If promptEntRs.Status <> PromptStatus.OK Then
            ed.WriteMessage("Exiting! Try Again !")
            Exit Sub
        End If
        Dim idEnt As ObjectId
        idEnt = promptEntRs.ObjectId

        Dim trans As Transaction = HostApplicationServices.WorkingDatabase.TransactionManager.StartTransaction()
        Dim civilDoc As CivilDocument = Autodesk.Civil.ApplicationServices.CivilApplication.ActiveDocument

        Try

            Dim alignId As ObjectId = Nothing
            Dim poptions As Autodesk.Civil.Land.DatabaseServices.PolylineOptions
            poptions.AddCurvesBetweenTangents = True
            poptions.EraseExistingEntities = True
            poptions.PlineId = idEnt
            ' Check the Alignment Style Name and labelSetName 
            ' To use the following default names you can use the "Align-6A.dwg " from Help\Civil Tutorials\Drawings\
            ' and make sure to create a empty Site named "Site 1"(if it is already not there in the DWG file), also draw a polyline to convert it to Alignment.

            alignId = Autodesk.Civil.Land.DatabaseServices.Alignment.Create(civilDoc, poptions, "Test_Alignment", "Site 1", "0", "Design Style", "All Labels")

            trans.Commit()
        Catch ex As Exception

            ed.WriteMessage("Exception Message is  : " + ex.Message.ToString())

        Finally
            trans.Dispose()
        End Try
    End Sub

 

End Class
